referrerpolicy=no-referrer-when-downgrade

Round

Type Alias Round 

pub type Round<T: Config> = StorageValue<_GeneratedPrefixForStorageRound<T>, u32, ValueQuery>;
Internal counter for the number of rounds.

This is useful for de-duplication of transactions submitted to the pool, and general diagnostics of the pallet.

This is merely incremented once per every time that an upstream elect is called.

Storage type is [StorageValue] with value type u32.

Aliased Type

pub struct Round<T: Config>(/* private fields */);